#!/bin/env python3

import yaml
from collections import OrderedDict
from unidecode import unidecode

contributions = OrderedDict( # sort contributions by starting page
  sorted(yaml.load(open('isipta15contrib.yaml')).items(),
         key=lambda x: x[1]['pages'][0]))

biblatex = ''

for key, entry in contributions.items():
  surnames = [unidecode(fullname.rsplit(maxsplit=1)[-1])
              for fullname in entry['authors']]
  id_stub = surnames.pop(0)
  if len(surnames) is 1:
    id_stub += '+' + surnames[0]
  if len(surnames) > 1:
    id_stub += '+' + ''.join(surname[0] for surname in surnames)
  biblatex += "@INPROCEEDINGS{{{}-ISIPTA15{},\n".format(id_stub, 'p' if entry['type'] == 'paper' else 'a')
  biblatex += "  AUTHOR = {{{}}},\n".format(' and '.join(entry['authors']))
  biblatex += "  TITLE = {{{}}},\n".format(entry['title'])
  biblatex += "  BOOKTITLE = {Proceedings of the Ninth International Symposium on Imprecise Probability: Theories and Applications},\n"
  biblatex += "  EDITOR = {Thomas Augustin and Serena Doria and Enrique Miranda and Erik Quaeghebeur},\n"
  biblatex += "  PAGES = {{{0[0]}--{0[1]}}},\n".format(entry['pages'])
  biblatex += "  URL = {{http://www.sipta.org/isipta15/data/{}/{}.pdf}},\n".format('paper' if entry['type'] == 'paper' else 'abstract', key)
  if 'keywords' in entry:
    biblatex += "  KEYWORDS = {{{}}},\n".format(', '.join(entry['keywords']))
  if 'abstract' in entry:
    biblatex += "  ABSTRACT = {{{}}},\n".format(entry['abstract'])
  biblatex += "  EVENTTITLE = {ISIPTA '15},\n"
  biblatex += "  EVENTDATE = {2015-07-20/2015-07-24},\n"
  biblatex += "  VENUE = {Pescara, Italy},\n"
  biblatex += "}\n\n"

# Ad hoc corrections
biblatex = biblatex.replace('Jasper De Bock', 'De Bock, Jasper')
biblatex = biblatex.replace('Arthur Van Camp', 'Van Camp, Arthur')
biblatex = biblatex.replace('Doria-ISIPTA15p,', 'Doria-ISIPTA15p_congl,', 1)
biblatex = biblatex.replace('Doria-ISIPTA15p,', 'Doria-ISIPTA15p_risk,', 1)

# Write to std-out
print(biblatex)
